const key = '7619409afc0d0a47e4139190db6d1665eaab2e49e6b0ef161e6fadc96c8ed6f3'

const hyperdrive = require('hyperdrive')
const memdb = require('memdb')
const {RDD, kv} = require('.')
const raf = require('random-access-file')
const swarm = require('hyperdrive-archive-swarm')
const level = require('level')

var drive = hyperdrive(level('uber'))
var archive = drive.createArchive(key, {sparse: true})

swarm(archive)

var out = drive.createArchive({file: name => raf('out/' + name)})

console.log(process.memoryUsage().rss)

// define transforms
var rdd = RDD(archive)
  .select(x => x.name === 'uber-raw-data-jul14.csv' || x.name === 'uber-raw-data-jun14.csv')
  .csv()
//.map(x => [x['Base'], JSON.stringify(x)])

rdd
  /*
  .partitionByKey(out).then(x => {
    var ws = out.createFileWriteStream('index.html')
    ws.write(`${JSON.stringify(rdd.marshal())}`)
    ws.end()
    console.log(process.memoryUsage().rss)
    swarm(out)
    console.log(out.key.toString('hex'))
    // process.exit()
  })
  */
  .map(row => kv(row['Base'], 1))
  .reduceByKey((x, y) => x + y).toArray(res => {
    console.log(res)
    console.log(process.memoryUsage().rss)
    process.exit()
  })
// .partition(row => {return row['DateTime']}, out).then(() => {console.log('ok')})
